==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/FTPException.h <==
// public class gnu.java.net.protocol.ftp.FTPException

// class file dependencies
// @dep_class c809b7774a244fcd gnu_java_net_protocol_ftp_FTPException
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_gnu_java_net_protocol_ftp_FTPException_H_
#define _JC_gnu_java_net_protocol_ftp_FTPException_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_FTPException$sub_refs	_jc_gnu_java_net_protocol_ftp_FTPException$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPException$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_FTPException$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPException$refs	_jc_gnu_java_net_protocol_ftp_FTPException$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPException$nonrefs	_jc_gnu_java_net_protocol_ftp_FTPException$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPException$object	_jc_gnu_java_net_protocol_ftp_FTPException$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_FTPException$vmethods	_jc_gnu_java_net_protocol_ftp_FTPException$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPException$vtable	_jc_gnu_java_net_protocol_ftp_FTPException$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPException$vtype	_jc_gnu_java_net_protocol_ftp_FTPException$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_FTPException$method$_init$835a0596c7987392(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPException$object *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *);

// Virtual methods
extern struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *_jc_gnu_java_net_protocol_ftp_FTPException$method$getResponse$ede989b65e35598e(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPException$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPException$method_info$getResponse$ede989b65e35598e;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_FTPException$vmethods {
	struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object	*(*getResponse$ede989b65e35598e)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPException$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_FTPException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_gnu_java_net_protocol_ftp_FTPException$vmethods	gnu_java_net_protocol_ftp_FTPException;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_FTPException$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_FTPException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPException$sub_refs {
	struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object	*response;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPException$refs {
    _jc_gnu_java_net_protocol_ftp_FTPException$sub_refs	gnu_java_net_protocol_ftp_FTPException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_gnu_java_net_protocol_ftp_FTPException$sub_nonrefs	gnu_java_net_protocol_ftp_FTPException;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_FTPException$object {
	_jc_gnu_java_net_protocol_ftp_FTPException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_FTPException$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_FTPException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_FTPException$vtype _jc_gnu_java_net_protocol_ftp_FTPException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_FTPException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_FTPException$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_FTPException_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/FTPException.h <==
// public class gnu.java.net.protocol.ftp.FTPException

// class file dependencies
// @dep_class c809b7774a244fcd gnu_java_net_protocol_ftp_FTPException
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_gnu_java_net_protocol_ftp_FTPException_H_
#define _JC_gnu_java_net_protocol_ftp_FTPException_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_FTPException$sub_refs	_jc_gnu_java_net_protocol_ftp_FTPException$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPException$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_FTPException$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPException$refs	_jc_gnu_java_net_protocol_ftp_FTPException$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPException$nonrefs	_jc_gnu_java_net_protocol_ftp_FTPException$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPException$object	_jc_gnu_java_net_protocol_ftp_FTPException$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_FTPException$vmethods	_jc_gnu_java_net_protocol_ftp_FTPException$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPException$vtable	_jc_gnu_java_net_protocol_ftp_FTPException$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPException$vtype	_jc_gnu_java_net_protocol_ftp_FTPException$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_FTPException$method$_init$835a0596c7987392(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPException$object *, struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object *_jc_gnu_java_net_protocol_ftp_FTPException$method$getResponse$ede989b65e35598e(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPException$method_info$getResponse$ede989b65e35598e;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_FTPException$vmethods {
	struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object	*(*getResponse$ede989b65e35598e)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_FTPException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_gnu_java_net_protocol_ftp_FTPException$vmethods	gnu_java_net_protocol_ftp_FTPException;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_FTPException$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_FTPException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPException$sub_refs {
	struct _jc_gnu_java_net_protocol_ftp_FTPResponse$object	*response;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPException$refs {
    _jc_gnu_java_net_protocol_ftp_FTPException$sub_refs	gnu_java_net_protocol_ftp_FTPException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_gnu_java_net_protocol_ftp_FTPException$sub_nonrefs	gnu_java_net_protocol_ftp_FTPException;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_FTPException$object {
	_jc_gnu_java_net_protocol_ftp_FTPException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_FTPException$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_FTPException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_FTPException$vtype _jc_gnu_java_net_protocol_ftp_FTPException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_FTPException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_FTPException$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_FTPException_H_ */
